<?php

namespace OrganizationsManagement\Controller;

use Exception;
use OrganizationsManagement\Traits\TResponse;
use Zeedhi\Framework\Controller\Simple;
use Zeedhi\Framework\DTO;
use OrganizationsManagement\Service\RedirecionamentoAssinatura as RedirecionamentoAssinaturaService;

class RedirecionamentoAssinatura extends Simple
{

    use TResponse;

    /**
     * @var RedirecionamentoAssinaturaService
     */
    private $redirecionamentoAssinaturaService;

    /**
     * RedirecionamentoAssinatura constructor.
     * @param RedirecionamentoAssinaturaService
     */
    public function __construct(RedirecionamentoAssinaturaService $redirecionamentoAssinaturaService)
    {
        $this->redirecionamentoAssinaturaService = $redirecionamentoAssinaturaService;
    }

    public function getParamCentrAssinatura()
    {
        try {
            $data = $this->redirecionamentoAssinaturaService->getParamCentrAssinatura();
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    } 

    public function getTipoDocCertsign()
    {
        try {
            $data = $this->redirecionamentoAssinaturaService->getTipoDocCertsign();
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    } 

    public function getRotasCentrAssinatura()
    {
        try {
            $data = $this->redirecionamentoAssinaturaService->getRotasCentrAssinatura();
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getLogCentrAssinatura()
    {
        try {
            $data = $this->redirecionamentoAssinaturaService->getLogCentrAssinatura();
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function updateParamCentrAssinatura(DTO\Request $request, DTO\Response $response)
    {
        try {
            $data = $request->getParameters();
            $this->redirecionamentoAssinaturaService->updateParamCentrAssinatura($data);
            $this->sendResponse(['success' => 'Registro(s) atualizado(s) com sucesso!'], 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function saveRotasAssinatura(DTO\Request $request, DTO\Response $response)
    {
        try {
            $rows = $request->getParameters();
            $this->redirecionamentoAssinaturaService->saveRotasAssinatura($rows);
            $this->sendResponse(['success' => 'Rota(s) atualizada(s) com sucesso!'], 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    } 

    public function deleteRotaAssinatura(DTO\Request $request, DTO\Response $response)
    {
        try {
            $rows = $request->getParameters();
            $this->redirecionamentoAssinaturaService->deleteRotaAssinatura($rows);
            $this->sendResponse(['success' => 'Rota(s) excluída(s) com sucesso!'], 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    /**
     * @param DTO\Request $request
     * @param DTO\Response $response
     * @throws Exception
     */
}
