<?php

namespace OrganizationsManagement\Repository;

use Doctrine\ORM\EntityManager;
use Teknisa\Model\Traits\TQuery;
use OrganizationsManagement\Util\InstanceProvider;

class CallCategory
{
    use TQuery;
    /**
     * @var EntityManager
     */
    private $entityManager;

    /**
     * ConsultaOperadorSAAS constructor.
     * @param EntityManager $entityManager
     */
    public function __construct(EntityManager $entityManager)
    {
        $this->entityManager = $entityManager;
    }

    public function findOrganization()
    {
        $query = <<<SQL
            SELECT *FROM ORGANIZACAO
SQL;
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $query);
    }

    public function saveAssuntoCallCategory($assunto)
    {
        $query = <<<SQL
        UPDATE CLASSIFICATION 
        SET CDASSUNTO = :CDASSUNTO
        WHERE ID = :ID
SQL;
        $params = array(
            'ID' => $assunto["ID"],
            'CDASSUNTO' => $assunto["CDASSUNTO"]
        );

        return  InstanceProvider::getEntityManager()->getConnection()->executeQuery($query, $params);
    }

    public function getCallCategory()
    {
        $query = <<<SQL
            SELECT CLA.ID, CLA.LABEL, ASS.NMASSUNTO, ASS.CDASSUNTO
                  FROM CLASSIFICATION CLA
                  JOIN CLASSIFICATION_PROJECT_TYPE CPT ON (CPT.CLASSIFICATION = CLA.ID AND CPT.TYPE = 'P')
                  JOIN PROJECT_TYPE PRT ON (PRT.ID = CPT.PROJECT_TYPE)
                  LEFT JOIN ASSUNTO ASS ON CLA.CDASSUNTO = ASS.CDASSUNTO
                 WHERE PRT.EXTERNALTYPE = 'P'
                   AND CLA.IS_TASK = 'Y'
                   AND CLA.CONTROL IS NULL
                   
              GROUP BY CLA.LABEL, CLA.ID, ASS.NMASSUNTO, ASS.CDASSUNTO
              ORDER BY CLA.LABEL
SQL;
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $query);
    }

    public function getFindAssuntoCallCategory()
    {
        $query = <<<SQL
        SELECT CDASSUNTO, NMASSUNTO
          FROM (SELECT CDASSUNTO , NMASSUNTO
                    FROM ASSUNTO
                  WHERE NOT (INSTR(NMASSUNTO, 'INATIVO') > 0)
                      AND CDASSUNTO IN(00010,00011,00012,00013,00021,00029,01800)) WHERE 1 = 1
            ORDER BY NMASSUNTO
SQL;
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $query);
    }
   
}