<?php

namespace OrganizationsManagement\Service;

use Doctrine\ORM\EntityManager;
use OrganizationsManagement\Util\Utilities;
use OrganizationsManagement\Repository\OrganizationReport as OrganizationReportRepository;


class OrganizationReport
{
    /**
     * @var EntityManager
     */
    private $entityManager;
    /**
     * @var OrganizationReportRepository
     */
    private $organizationReportRepository;

    public function __construct(EntityManager $entityManager, OrganizationReportRepository $organizationReportRepository)
    {
        $this->entityManager = $entityManager;
        $this->organizationReportRepository = $organizationReportRepository;
    }

    public function organizationReport($dynamicFilter, $page, $pageSize, $order)
    {
        $limit  = intval($pageSize);
        $offset = (intval($page) - 1) * intval($pageSize);
        $elementFilter = '';
        $redirectionFilter = '';
        $conditionsQuery = '';
        $dynamicFilter = Utilities::decodificarDynamicFilter($dynamicFilter);
        if (!empty($dynamicFilter['LABEL'])) {
            $labelValue = $dynamicFilter['LABEL'];
            $elementFilter = $this->buildFilterElements($labelValue[0]['value']);
            unset($dynamicFilter['LABEL']);
        }
        if (!empty($dynamicFilter['HAS_REDIRECTION'])) {
            $hasRedirectionValue = $dynamicFilter['HAS_REDIRECTION'];
            $redirectionFilter = $this->buildRedirectionFilterWithElements($hasRedirectionValue[0]['value']);
            unset($dynamicFilter['HAS_REDIRECTION']);
        }

        return $this->organizationReportRepository->organizationReport($elementFilter, $redirectionFilter, $dynamicFilter);
    }

    private function buildFilterElements($value)
    {
        return "AND EL.NRPRODUTO_ELEMENTO_ID IN (SELECT ID
                                                                FROM OM_PRODUTO_ELEMENTO
                                                                WHERE UPPER(LABEL) LIKE UPPER('$value'))";
    }

    private function buildRedirectionFilterWithElements($value)
    {
        if ($value == 'S') {
            return " AND (OG.DSURLREDIRECT IS NOT NULL OR OG.IDUTREDIRECTRC = 'S')";
        } else {
            return " AND (OG.DSURLREDIRECT IS NULL AND OG.IDUTREDIRECTRC = 'N')";
        }
    }

    public function getOrganizationReport($projectId, $elementProductOrg)
    {
        $data =  $this->organizationReportRepository->getOrganizationReport($projectId, $elementProductOrg);
        $data['data'] = Utilities::fixParentsForTreeGrid($data['data'], 'ID', 'PARENT_ID');
        if ($data) {
            $data['data'] = Utilities::generateTypeElementTreeGrid($data['data']);
            return $data;
        } else {
            return array();
        }
    }

    public function getOrganizacaoName()
    {
        return $this->organizationReportRepository->organizationReport();
    }

    public function getOrganizationReportCountry()
    {
        return $this->organizationReportRepository->getOrganizationReportCountry();
    }

    public function getOrganizationReportState($idPais)
    {
        return $this->organizationReportRepository->obtemPorIdPais($idPais);
    }

    public function getOrganizationReportCity($siglaEstado, $idPais)
    {
        return $this->organizationReportRepository->obtemPorSiglaEstado($siglaEstado, $idPais);
    }
}
