CREATE OR REPLACE PROCEDURE AGENDAMENTO_OBRIGACAO (
    P_NMOBRIGACAO IN VARCHAR2,
    P_IDTIPO IN VARCHAR,                 
    P_CDEMPRESA IN VARCHAR,              
    P_IDTIPOINSC IN VARCHAR,            
    P_CDINSCRICAO IN VARCHAR, 
    p_tipo_recorrencia IN VARCHAR2,
    p_dtinicial IN DATE,
    p_dtfinal IN DATE, 
    P_CDUNIDADECAL IN VARCHAR,
    P_IDTRATAMENTO IN VARCHAR,
    P_IDTPCALEND  IN VARCHAR,
    P_IDALERTEMAIL IN VARCHAR,   
    P_NRQUANTDIAS IN NUMBER,
    p_nrorg IN NUMBER       
) AS
    v_dtinicial DATE := p_dtinicial;
    v_dtfinal DATE := NVL(p_dtfinal, p_dtinicial);
    v_qtddias NUMBER := 0;
    v_venc DATE;
    v_nrorg NUMBER := p_nrorg; 
    v_nrseqlote NUMBER; 

    -- Ajusta o número de dias com base no tipo de recorrência
    BEGIN
        -- Define os dias com base no tipo de recorrência
        IF p_tipo_recorrencia = 'U' THEN
            v_qtddias := 0;
        ELSIF p_tipo_recorrencia = 'W' THEN
            v_qtddias := 7;
        ELSIF p_tipo_recorrencia = 'Q' THEN
            v_qtddias := 15;
        ELSIF p_tipo_recorrencia = 'M' THEN
            v_qtddias := 30;
        ELSIF p_tipo_recorrencia = 'T' THEN
            v_qtddias := 90;
        ELSIF p_tipo_recorrencia = 'S' THEN
            v_qtddias := 180;
        ELSIF p_tipo_recorrencia = 'A' THEN
            v_qtddias := 365;
        ELSE
            RAISE_APPLICATION_ERROR(-20001, 'Tipo de recorrência inválido.');
        END IF;

        -- Gera o próximo valor de NRSEQLOTE da sequência
        SELECT SEQ_NRSEQLOTE.NEXTVAL INTO v_nrseqlote FROM DUAL;

        -- Loop para inserir as obrigações
        WHILE v_dtinicial <= v_dtfinal LOOP
            -- Chama a função de consistência para verificar o feriado
            CONSISTE_FERI_FISCAL(P_CDUNIDADECAL,v_dtinicial,v_venc,'S','', P_IDTPCALEND, P_IDTRATAMENTO);
            
            -- Verifica se a data de vencimento é válida (caso necessário)
            IF v_venc IS NOT NULL THEN
                -- Inserção no banco de dados com os valores das sequências
                INSERT INTO AGENDATRIB (
                    NRAGENDATRIB, 
                    NMOBRIGACAO, 
                    IDTIPO, 
                    CDEMPRESA, 
                    IDTIPOINSC, 
                    CDINSCRICAO, 
                    DTINICIAL, 
                    IDALERTEMAIL, 
                    NRQUANTDIAS, 
                    NRSEQLOTE
                ) 
                VALUES (
                    SEQ_NRAGENDATRIB.NEXTVAL,   -- Gera o próximo valor de NRAGENDATRIB da sequência    
                    P_NMOBRIGACAO,        
                    P_IDTIPO,             
                    P_CDEMPRESA,          
                    P_IDTIPOINSC,         
                    P_CDINSCRICAO,        
                    V_VENC,         
                    P_IDALERTEMAIL,       
                    P_NRQUANTDIAS,        
                    V_nrseqlote          
                );
            END IF;

            -- Atualiza a data inicial com a quantidade de dias de acordo com a recorrência
            v_dtinicial := v_dtinicial + v_qtddias;
        END LOOP;
    END;
/